==> intel-media-driver-non-free_22.3.1+ds1.orig.tar.xz: media-driver-intel-media-22.3.1/media_softlet/agnostic/common/codec/hal/enc/shared/pipeline/encode_pipeline_adapter.h <==
/*
* Copyright (c) 2018-2020, Intel Corporation
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
*/
//!
//! \file     encode_pipeline_adapter.h
//! \brief    Defines the interface to adapt to encode pipeline
//!

#ifndef __ENCODE_PIPELINE_ADAPTER_H__
#define __ENCODE_PIPELINE_ADAPTER_H__

#include "codechal.h"
#include "codechal_encoder_base.h"

class EncoderPipelineAdapter: public Codechal
{
public:
    //!
    //! \brief    Constructor
    //! \param    [in] hwInterface
    //!           Hardware interface
    //! \param    [in] debugInterface
    //!           Debug interface
    //!
    EncoderPipelineAdapter(
        CodechalHwInterface    *hwInterface,
        CodechalDebugInterface *debugInterface) : Codechal(hwInterface, debugInterface)
    {
        m_apogeiosEnable = true;
        m_mfeEncodeParams.submitIndex  = 0;
        m_mfeEncodeParams.submitNumber = 1; //By default we only use one stream
        m_mfeEncodeParams.streamId  = 0;
    };

    uint32_t                        m_mvOffset = 0;                 //!< MV data offset, in 64 byte
    uint32_t                        m_mbcodeBottomFieldOffset = 0;  //!< MB code offset frame/TopField - zero, BottomField - nonzero
    uint32_t                        m_mvBottomFieldOffset = 0;      //!< MV data offset frame/TopField - zero, BottomField - nonzero

    bool                            m_vdencEnabled = false;         //!< Vdenc enabled flag

    bool                            m_mfeEnabled = false;                //!< Mfe enabled
    bool                            m_mfeMbEncEanbled = false;           //!< Mfe MBEnc kernel enabled
    bool                            m_mfeLastStream = false;             //!< Is last stream during this submission
    bool                            m_mfeFirstStream = false;            //!< Is first stream during this submission
    bool                            m_mfeInitialized = false;            //!< Used for initializing MFE resources during first execute
    MfeParams                       m_mfeEncodeParams = {0};             //!< Mfe encode params during this submission
    MfeSharedState                  *m_mfeEncodeSharedState = nullptr;   //!< shared state from the parent context

MEDIA_CLASS_DEFINE_END(EncoderPipelineAdapter)
};
#endif // !__ENCODE_PIPELINE_ADAPTER_H__

==> intel-media-driver-non-free_25.4.2+ds1.orig.tar.xz: media-driver-intel-media-25.4.2/media_softlet/agnostic/common/codec/hal/enc/shared/pipeline/encode_pipeline_adapter.h <==
/*
* Copyright (c) 2018-2020, Intel Corporation
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included
* in all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
* OTHER DEALINGS IN THE SOFTWARE.
*/
//!
//! \file     encode_pipeline_adapter.h
//! \brief    Defines the interface to adapt to encode pipeline
//!

#ifndef __ENCODE_PIPELINE_ADAPTER_H__
#define __ENCODE_PIPELINE_ADAPTER_H__

#include "codechal_common.h"

class EncoderPipelineAdapter: public Codechal
{
public:
    //!
    //! \brief    Constructor
    //! \param    [in] hwInterface
    //!           Hardware interface
    //! \param    [in] debugInterface
    //!           Debug interface
    //!
    EncoderPipelineAdapter(
        CodechalHwInterfaceNext    *hwInterface,
        CodechalDebugInterface *debugInterface) : Codechal(hwInterface, debugInterface)
    {
        m_apogeiosEnable = true;
    };

    uint32_t                        m_mvOffset = 0;                 //!< MV data offset, in 64 byte
    uint32_t                        m_mbcodeBottomFieldOffset = 0;  //!< MB code offset frame/TopField - zero, BottomField - nonzero
    uint32_t                        m_mvBottomFieldOffset = 0;      //!< MV data offset frame/TopField - zero, BottomField - nonzero

    bool                            m_vdencEnabled = false;         //!< Vdenc enabled flag

MEDIA_CLASS_DEFINE_END(EncoderPipelineAdapter)
};
#endif // !__ENCODE_PIPELINE_ADAPTER_H__
